==> emacspeak_26.0.orig.tar.gz: emacspeak-26.0.orig/lisp/emacspeak-cus-load.el <==
;;; cus-load.el --- automatically extracted custom dependencies
;;
;;; Code:

(put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
(put 'emacspeak-url-template 'custom-loads '(emacspeak-url-template))
(put 'dtk 'custom-loads '(dtk-speak))
(put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
(put 'emacspeak-tnt 'custom-loads '(emacspeak-tnt))
(put 'emacspeak-forms 'custom-loads '(emacspeak-forms))
(put 'emacspeak-rss 'custom-loads '(emacspeak-rss))
(put 'speedbar 'custom-loads '(emacspeak-speedbar))
(put 'emacspeak-xslt 'custom-loads '(emacspeak-xslt))
(put 'emacspeak-eshell 'custom-loads '(emacspeak-eshell))
(put 'emacspeak-speak 'custom-loads '(emacspeak-speak emacspeak-advice emacspeak-wizards))
(put 'emacspeak-outline 'custom-loads '(emacspeak-outline))
(put 'flyspell 'custom-loads '(emacspeak-flyspell))
(put 'eshell 'custom-loads '(emacspeak-eshell))
(put 'emacspeak-realaudio 'custom-loads '(emacspeak-realaudio))
(put 'emacspeak-imenu 'custom-loads '(emacspeak-imenu))
(put 'widget 'custom-loads '(emacspeak-widget))
(put 'gnus 'custom-loads '(emacspeak-gnus))
(put 'emacspeak-eperiodic 'custom-loads '(emacspeak-eperiodic))
(put 'emacspeak-ocr 'custom-loads '(emacspeak-ocr))
(put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
(put 'forms 'custom-loads '(emacspeak-forms))
(put 'tts 'custom-loads '(emacspeak-setup dtk-speak))
(put 'w3m 'custom-loads '(emacspeak-w3m))
(put 'gnotebook 'custom-loads '(gnotebook))
(put 'emacspeak-pronounce 'custom-loads '(emacspeak-pronounce))
(put 'emacspeak 'custom-loads '(emacspeak-add-log emacspeak-keymap emacspeak-atom emacspeak-aumix emacspeak-daisy emacspeak-dismal emacspeak-ediff emacspeak-wizards emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-m-player emacspeak emacspeak-message emacspeak-midge emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-realaudio emacspeak-replace emacspeak-rss emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-table-ui emacspeak-view-process emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-websearch emacspeak-widget emacspeak-xml-shell emacspeak-xslt dtk-speak voice-setup))
(put 'emacspeak-xml-shell 'custom-loads '(emacspeak-xml-shell))
(put 'emacspeak-calendar 'custom-loads '(emacspeak-calendar))
(put 'emacspeak-amphetadesk 'custom-loads '(emacspeak-amphetadesk))
(put 'emacspeak-info 'custom-loads '(emacspeak-info))
(put 'atom-blogger 'custom-loads '("old-atom-blogger"))
(put 'isearch 'custom-loads '(emacspeak-replace))
(put 'emacspeak-eudc 'custom-loads '(emacspeak-eudc))
(put 'vm 'custom-loads '(emacspeak-vm))
(put 'w3 'custom-loads '(emacspeak-w3))
(put 'emacspeak-table 'custom-loads '(emacspeak-table-ui))
(put 'emacspeak-wizards 'custom-loads '(emacspeak-wizards))
(put 'emacspeak-speedbar 'custom-loads '(emacspeak-speedbar))
(put 'accessibility 'custom-loads '(emacspeak))
(put 'emacspeak-dired 'custom-loads '(emacspeak-dired))
(put 'emacspeak-xslide 'custom-loads '(emacspeak-xslide))
(put 'emacspeak-daisy 'custom-loads '(emacspeak-daisy))
(put 'emacspeak-sounds 'custom-loads '(emacspeak-sounds))
(put 'emacspeak-eterm 'custom-loads '(emacspeak-eterm))
(put 'emacspeak-ispell 'custom-loads '(emacspeak-ispell))
(put 'emacspeak-jabber 'custom-loads '(emacspeak-jabber))
(put 'emacspeak-erc 'custom-loads '(emacspeak-erc))
(put 'emacspeak-vm 'custom-loads '(emacspeak-vm))
(put 'emacspeak-custom 'custom-loads '(emacspeak-custom))
(put 'emacspeak-w3 'custom-loads '(emacspeak-w3))
(put 'eudc 'custom-loads '(emacspeak-eudc))
(put 'cd-tool 'custom-loads '(cd-tool))
(put 'greader 'custom-loads '(greader))
(put 'applications 'custom-loads '("old-atom-blogger" emacspeak g))
(put 'g-auth 'custom-loads '(g-auth))
(put 'emacspeak-midge 'custom-loads '(emacspeak-midge))
(put 'emacspeak-madplay 'custom-loads '(emacspeak-madplay))
(put 'message 'custom-loads '(emacspeak-message))
(put 'emacspeak-message 'custom-loads '(emacspeak-message))
(put 'gcal 'custom-loads '(gcal))
(put 'emacspeak-personality 'custom-loads '(emacspeak-personality))
(put 'gsheet 'custom-loads '(gsheet))
(put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
(put 'emacspeak-atom 'custom-loads '(emacspeak-atom))
(put 'emacspeak-m-player 'custom-loads '(emacspeak-m-player))
(put 'voice-fonts 'custom-loads '(voice-setup))
(put 'gblogger 'custom-loads '(gblogger))
(put 'emacspeak-view-process 'custom-loads '(emacspeak-view-process))
(put 'emacspeak-dismal 'custom-loads '(emacspeak-dismal))
(put 'aplications 'custom-loads '(emacspeak-amphetadesk))
(put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
(put 'emacspeak-ediff 'custom-loads '(emacspeak-ediff))
(put 'emacspeak-spek 'custom-loads '(emacspeak-advice))
(put 'g 'custom-loads '(g-utils g-auth gblogger gcal gnotebook greader gsheet))
(put 'emacspeak-remote 'custom-loads '(emacspeak-remote))
(put 'emacspeak-hide 'custom-loads '(emacspeak-hide))
;; These are for handling :version.  We need to have a minimum of
;; information so `customize-changed-options' could do its job.

;; For groups we set `custom-version', `group-documentation' and
;; `custom-tag' (which are shown in the customize buffer), so we
;; don't have to load the file containing the group.

;; `custom-versions-load-alist' is an alist that has as car a version
;; number and as elts the files that have variables or faces that
;; contain that version. These files should be loaded before showing
;; the customization buffer that `customize-changed-options'
;; generates.

;; This macro is used so we don't modify the information about
;; variables and groups if it's already set. (We don't know when
;; cus-load.el is going to be loaded and at that time some of the
;; files might be loaded and some others might not).
(defmacro custom-put-if-not (symbol propname value)
  `(unless (get ,symbol ,propname)
     (put ,symbol ,propname ,value)))


(defvar custom-versions-load-alist nil
 "For internal use by custom.")

(provide 'cus-load)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; End:
;;; cus-load.el ends here

==> emacspeak_28.0.orig.tar.gz: emacspeak-28.0.orig/lisp/emacspeak-cus-load.el <==
;;; cus-load.el --- automatically extracted custom dependencies
;;
;;; Code:

(put 'emacspeak-w3m 'custom-loads '(emacspeak-w3m))
(put 'emacspeak-url-template 'custom-loads '(emacspeak-url-template))
(put 'dtk 'custom-loads '(dtk-speak))
(put 'emacspeak-gnus 'custom-loads '(emacspeak-gnus))
(put 'emacspeak-tnt 'custom-loads '(emacspeak-tnt))
(put 'amixer 'custom-loads '(amixer))
(put 'emacspeak-forms 'custom-loads '(emacspeak-forms))
(put 'emacspeak-rss 'custom-loads '(emacspeak-webutils))
(put 'speedbar 'custom-loads '(emacspeak-speedbar))
(put 'emacspeak-xslt 'custom-loads '(emacspeak-xslt))
(put 'emacspeak-eshell 'custom-loads '(emacspeak-eshell))
(put 'emacspeak-speak 'custom-loads '(emacspeak-speak emacspeak-wizards emacspeak-advice))
(put 'emacspeak-outline 'custom-loads '(emacspeak-outline))
(put 'flyspell 'custom-loads '(emacspeak-flyspell))
(put 'eshell 'custom-loads '(emacspeak-eshell))
(put 'emacspeak-realaudio 'custom-loads '(emacspeak-realaudio))
(put 'emacspeak-imenu 'custom-loads '(emacspeak-imenu))
(put 'emacspeak-webutils 'custom-loads '(emacspeak-webutils))
(put 'widget 'custom-loads '(emacspeak-widget))
(put 'gnus 'custom-loads '(emacspeak-gnus))
(put 'emacspeak-piglets 'custom-loads '(emacspeak-piglets))
(put 'emacspeak-eperiodic 'custom-loads '(emacspeak-eperiodic))
(put 'emacspeak-ocr 'custom-loads '(emacspeak-ocr))
(put 'emacspeak-websearch 'custom-loads '(emacspeak-websearch))
(put 'forms 'custom-loads '(emacspeak-forms))
(put 'tts 'custom-loads '(emacspeak-setup dtk-speak))
(put 'w3m 'custom-loads '(emacspeak-w3m))
(put 'emacspeak-webspace 'custom-loads '(emacspeak-webspace))
(put 'emacspeak-pronounce 'custom-loads '(emacspeak-pronounce))
(put 'emacspeak 'custom-loads '(emacspeak-add-log emacspeak-alsaplayer emacspeak-keymap emacspeak-webutils emacspeak-aumix emacspeak-daisy emacspeak-dismal emacspeak-ediff emacspeak-wizards emacspeak-erc emacspeak-eshell emacspeak-eterm emacspeak-eudc emacspeak-flyspell emacspeak-forms emacspeak-gnus emacspeak-ido emacspeak-ispell emacspeak-m-player emacspeak emacspeak-message emacspeak-midge emacspeak-moz emacspeak-nxml emacspeak-ocr emacspeak-pronounce emacspeak-realaudio emacspeak-replace emacspeak-sounds emacspeak-speak emacspeak-speedbar emacspeak-table-ui emacspeak-view-process emacspeak-vm emacspeak-w3 emacspeak-w3m emacspeak-we emacspeak-webmarks emacspeak-websearch emacspeak-widget emacspeak-xml-shell emacspeak-xslt dtk-speak voice-setup))
(put 'emacspeak-xml-shell 'custom-loads '(emacspeak-xml-shell))
(put 'emacspeak-calendar 'custom-loads '(emacspeak-calendar))
(put 'emacspeak-amphetadesk 'custom-loads '(emacspeak-amphetadesk))
(put 'emacspeak-info 'custom-loads '(emacspeak-info))
(put 'isearch 'custom-loads '(emacspeak-replace))
(put 'emacspeak-eudc 'custom-loads '(emacspeak-eudc))
(put 'vm 'custom-loads '(emacspeak-vm))
(put 'w3 'custom-loads '(emacspeak-w3))
(put 'emacspeak-table 'custom-loads '(emacspeak-table-ui))
(put 'emacspeak-wizards 'custom-loads '(emacspeak-wizards))
(put 'emacspeak-speedbar 'custom-loads '(emacspeak-speedbar))
(put 'accessibility 'custom-loads '(emacspeak))
(put 'emacspeak-dired 'custom-loads '(emacspeak-dired))
(put 'emacspeak-xslide 'custom-loads '(emacspeak-xslide))
(put 'emacspeak-daisy 'custom-loads '(emacspeak-daisy))
(put 'emacspeak-sounds 'custom-loads '(emacspeak-sounds))
(put 'emacspeak-eterm 'custom-loads '(emacspeak-eterm))
(put 'emacspeak-ispell 'custom-loads '(emacspeak-ispell))
(put 'emacspeak-jabber 'custom-loads '(emacspeak-jabber))
(put 'emacspeak-erc 'custom-loads '(emacspeak-erc))
(put 'emacspeak-we 'custom-loads '(emacspeak-we))
(put 'emacspeak-vm 'custom-loads '(emacspeak-vm))
(put 'emacspeak-custom 'custom-loads '(emacspeak-custom))
(put 'emacspeak-w3 'custom-loads '(emacspeak-w3))
(put 'eudc 'custom-loads '(emacspeak-eudc))
(put 'cd-tool 'custom-loads '(cd-tool))
(put 'applications 'custom-loads '(emacspeak))
(put 'emacspeak-midge 'custom-loads '(emacspeak-midge))
(put 'emacspeak-madplay 'custom-loads '(emacspeak-madplay))
(put 'message 'custom-loads '(emacspeak-message))
(put 'emacspeak-message 'custom-loads '(emacspeak-message))
(put 'emacspeak-personality 'custom-loads '(emacspeak-personality))
(put 'emacspeak-aumix 'custom-loads '(emacspeak-aumix))
(put 'emacspeak-atom 'custom-loads '(emacspeak-webutils))
(put 'emacspeak-xsl 'custom-loads '(emacspeak-webutils))
(put 'emacspeak-m-player 'custom-loads '(emacspeak-m-player))
(put 'voice-fonts 'custom-loads '(voice-setup))
(put 'emacspeak-view-process 'custom-loads '(emacspeak-view-process))
(put 'emacspeak-dismal 'custom-loads '(emacspeak-dismal))
(put 'aplications 'custom-loads '(emacspeak-amphetadesk))
(put 'emacspeak-webmarks 'custom-loads '(emacspeak-webmarks))
(put 'emacspeak-alsaplayer 'custom-loads '(emacspeak-alsaplayer))
(put 'emacspeak-ediff 'custom-loads '(emacspeak-ediff))
(put 'emacspeak-spek 'custom-loads '(emacspeak-advice))
(put 'emacspeak-remote 'custom-loads '(emacspeak-remote))
(put 'emacspeak-hide 'custom-loads '(emacspeak-hide))
;; These are for handling :version.  We need to have a minimum of
;; information so `customize-changed-options' could do its job.

;; For groups we set `custom-version', `group-documentation' and
;; `custom-tag' (which are shown in the customize buffer), so we
;; don't have to load the file containing the group.

;; `custom-versions-load-alist' is an alist that has as car a version
;; number and as elts the files that have variables or faces that
;; contain that version. These files should be loaded before showing
;; the customization buffer that `customize-changed-options'
;; generates.

;; This macro is used so we don't modify the information about
;; variables and groups if it's already set. (We don't know when
;; cus-load.el is going to be loaded and at that time some of the
;; files might be loaded and some others might not).
(defmacro custom-put-if-not (symbol propname value)
  `(unless (get ,symbol ,propname)
     (put ,symbol ,propname ,value)))


(defvar custom-versions-load-alist nil
 "For internal use by custom.")

(provide 'cus-load)

;; Local Variables:
;; version-control: never
;; no-byte-compile: t
;; no-update-autoloads: t
;; End:
;;; cus-load.el ends here
